@@ -303,11 +303,7 @@ static void create_screens(NotifyDaemon* daemon)
 
 		daemon->priv->screens[i] = g_new0(NotifyScreen, 1);
 
-		#if GTK_CHECK_VERSION(3, 0, 0)
 			daemon->priv->screens[i]->workarea_atom = XInternAtom(GDK_DISPLAY_XDISPLAY(gdk_display_get_default()), "_NET_WORKAREA", True);
-		#else
-			daemon->priv->screens[i]->workarea_atom = XInternAtom(GDK_DISPLAY(), "_NET_WORKAREA", True);
-		#endif
 
 		gdkwindow = gdk_screen_get_root_window(screen);
 		gdk_window_add_filter(gdkwindow, (GdkFilterFunc) screen_xevent_filter, daemon->priv->screens[i]);
@@ -1081,8 +1077,9 @@ static void window_clicked_cb(GtkWindow* nw, GdkEventButton* button, NotifyDaemo
 static void url_clicked_cb(GtkWindow* nw, const char *url)
 {
 	NotifyDaemon* daemon;
-	char* escaped_url;
-	char* cmd = NULL;
+	gchar *escaped_url;
+	gchar *cmd = NULL;
+	gchar *found = NULL;
 
 	daemon = NW_GET_DAEMON(nw);
 
@@ -1091,15 +1088,15 @@ static void url_clicked_cb(GtkWindow* nw, const char *url)
 
 	escaped_url = g_shell_quote (url);
 
-	if (g_find_program_in_path ("gvfs-open") != NULL)
+	if ((found = g_find_program_in_path ("gvfs-open")) != NULL)
 	{
 		cmd = g_strdup_printf ("gvfs-open %s", escaped_url);
 	}
-	else if (g_find_program_in_path ("xdg-open") != NULL)
+	else if ((found = g_find_program_in_path ("xdg-open")) != NULL)
 	{
 		cmd = g_strdup_printf ("xdg-open %s", escaped_url);
 	}
-	else if (g_find_program_in_path ("firefox") != NULL)
+	else if ((found = g_find_program_in_path ("firefox")) != NULL)
 	{
 		cmd = g_strdup_printf ("firefox %s", escaped_url);
 	}
@@ -1108,6 +1105,7 @@ static void url_clicked_cb(GtkWindow* nw, const char *url)
 		g_warning ("Unable to find a browser.");
 	}
 
+	g_free (found);
 	g_free (escaped_url);
 
 	if (cmd != NULL)
@@ -1152,11 +1150,7 @@ static gboolean fullscreen_window_exists(GtkWidget* nw)
 	WnckWorkspace* wnck_workspace;
 	GList* l;
 
-	#if GTK_CHECK_VERSION (3, 0, 0) || ((GDK_PIXBUF_MAJOR == 2) && (GDK_PIXBUF_MINOR < 22))
 		wnck_screen = wnck_screen_get(GDK_SCREEN_XNUMBER(gdk_window_get_screen(gtk_widget_get_window(nw))));
-	#else
-		wnck_screen = wnck_screen_get(GDK_SCREEN_XNUMBER(gdk_drawable_get_screen(GDK_DRAWABLE(GTK_WIDGET(nw)->window))));
-	#endif
 
 	wnck_screen_force_update (wnck_screen);
 
