@@ -144,6 +144,9 @@ fill_background(GtkWidget *widget, WindowData *windata, cairo_t *cr)
 static void
 draw_pie(GtkWidget *pie, WindowData *windata, cairo_t *cr)
 {
+	if (windata->timeout == 0)
+		return;
+
 	gdouble arc_angle = 1.0 - (gdouble)windata->remaining / (gdouble)windata->timeout;
 	cairo_set_source_rgba (cr, 1.0, 0.4, 0.0, 0.3);
 	cairo_move_to(cr, PIE_RADIUS, PIE_RADIUS);
@@ -171,11 +174,7 @@ paint_window(GtkWidget *widget,
 #endif
 
 	if (windata->width == 0) {
-#if GTK_CHECK_VERSION(3, 0, 0)
 		gtk_widget_get_allocation(windata->win, &allocation);
-#else
-		allocation = windata->win->allocation;
-#endif
 		windata->width = allocation.width;
 		windata->height = allocation.height;    
 	}
@@ -221,25 +220,17 @@ paint_window(GtkWidget *widget,
 #endif
 	}
 
-#if GTK_CHECK_VERSION(3, 0, 0)
 	context = gdk_cairo_create(gtk_widget_get_window(widget));
-#else 
-	context = gdk_cairo_create(widget->window);
-#endif
 
 	cairo_set_operator(context, CAIRO_OPERATOR_SOURCE);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	surface = cairo_surface_create_similar(cairo_get_target(context),
 										   CAIRO_CONTENT_COLOR_ALPHA,
 										   windata->width,
 										   windata->height);
+#if GTK_CHECK_VERSION (3, 0, 0)
 	cairo_set_source_surface (cr, surface, 0, 0);
 #else
-	surface = cairo_surface_create_similar(cairo_get_target(context),
-										   CAIRO_CONTENT_COLOR_ALPHA,
-										   widget->allocation.width,
-										   widget->allocation.height);
 	cr = cairo_create(surface);
 #endif
 
@@ -287,11 +278,7 @@ countdown_expose_cb(GtkWidget *pie,
 	cairo_t *cr;
 #endif
 
-#if GTK_CHECK_VERSION(3, 0, 0)
 	context = gdk_cairo_create(gtk_widget_get_window(pie));
-#else 
-	context = gdk_cairo_create(pie->window);
-#endif
 
 	cairo_set_operator(context, CAIRO_OPERATOR_SOURCE);
 #if GTK_CHECK_VERSION (3, 0, 0)
@@ -498,10 +485,8 @@ create_notification(UrlClickedCb url_clicked)
 	atkobj = gtk_widget_get_accessible(windata->body_label);
 	atk_object_set_description(atkobj, "Notification body text.");
 
-    /* Disabled for now */
 	alignment = gtk_alignment_new(1, 0.5, 0, 0);
 	gtk_widget_show(alignment);
-    gtk_widget_hide(alignment);
 	gtk_box_pack_start(GTK_BOX(vbox), alignment, FALSE, TRUE, 0);
 
 	windata->actions_box = gtk_hbox_new(FALSE, 6);
@@ -585,11 +570,7 @@ add_notification_action(GtkWindow *nw, const char *text, const char *key,
 
 	g_assert(windata != NULL);
 
-#if GTK_CHECK_VERSION(3, 0, 0)
-	if (gtk_widget_get_visible(windata->actions_box))
-#else 
-	if (!GTK_WIDGET_VISIBLE(windata->actions_box))
-#endif
+	if (!gtk_widget_get_visible(windata->actions_box))
 	{
 		GtkWidget *alignment;
 
@@ -626,11 +607,7 @@ add_notification_action(GtkWindow *nw, const char *text, const char *key,
 	buf = g_strdup_printf("stock_%s", key);
 	pixbuf = gtk_icon_theme_load_icon(
 		gtk_icon_theme_get_for_screen(
-#if GTK_CHECK_VERSION(3, 0, 0)
 			gdk_window_get_screen(gtk_widget_get_window(GTK_WIDGET(nw)))),
-#else 
-			gdk_drawable_get_screen(GTK_WIDGET(nw)->window)),
-#endif
 		buf, 16, GTK_ICON_LOOKUP_USE_BUILTIN, NULL);
 	g_free(buf);
 
@@ -667,11 +644,7 @@ clear_notification_actions(GtkWindow *nw)
 
 	gtk_widget_hide(windata->actions_box);
 	gtk_container_foreach(GTK_CONTAINER(windata->actions_box),
-#if GTK_CHECK_VERSION (3, 0, 0)
 						  (GtkCallback)g_object_unref, NULL);
-#else
-						  (GtkCallback)gtk_object_destroy, NULL);
-#endif
 }
 
 /* Move notification window */
